.. mdinclude:: ../README.md

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   doc/readme
   doc/gettingstarted
   doc/toolbox
   doc/changelog
   doc/contributing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
